You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by hi...@apache.org on 2016/06/15 16:42:57 UTC

[76/97] [abbrv] incubator-geode git commit: GEODE-1528: CacheFactory javadocs point to the wrong place for DistributedSystem properties

GEODE-1528: CacheFactory javadocs point to the wrong place for DistributedSystem properties

Modified DistributedSystem and CacheFactory to point to the new
ConfigurationProperties interface for property names and meanings.


Project: http://git-wip-us.apache.org/repos/asf/incubator-geode/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-geode/commit/e831aa06
Tree: http://git-wip-us.apache.org/repos/asf/incubator-geode/tree/e831aa06
Diff: http://git-wip-us.apache.org/repos/asf/incubator-geode/diff/e831aa06

Branch: refs/heads/GEODE-1372
Commit: e831aa06268e3d80bb13eec56b9da1b863d5e0f1
Parents: d28ac95
Author: Bruce Schuchardt <bs...@pivotal.io>
Authored: Fri Jun 10 14:16:15 2016 -0700
Committer: Bruce Schuchardt <bs...@pivotal.io>
Committed: Fri Jun 10 14:17:56 2016 -0700

----------------------------------------------------------------------
 .../main/java/com/gemstone/gemfire/cache/CacheFactory.java    | 7 +++++--
 .../com/gemstone/gemfire/distributed/DistributedSystem.java   | 6 ++++--
 2 files changed, 9 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/e831aa06/geode-core/src/main/java/com/gemstone/gemfire/cache/CacheFactory.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/com/gemstone/gemfire/distributed/DistributedSystem.java b/geode-core/src/main/java/com/gemstone/gemfire/distributed/DistributedSystem.java
old mode 100755
new mode 100644
index d14d5a9..46feef9
--- a/geode-core/src/main/java/com/gemstone/gemfire/distributed/DistributedSystem.java
+++ b/geode-core/src/main/java/com/gemstone/gemfire/distributed/DistributedSystem.java
@@ -109,8 +109,10 @@ public abstract class DistributedSystem implements StatisticsFactory {
 
   /**
    * Connects to a GemFire distributed system with a configuration
-   * supplemented by the given properties.
-   * <P>The actual configuration attribute values used to connect comes
+   * supplemented by the given properties.  See {@linkplain ConfigurationProperties}
+   * for available GemFire properties and their meanings.
+   * <P>
+   * The actual configuration attribute values used to connect comes
    * from the following sources:
    * <OL>
    * <LI>System properties. If a system property named
diff --git a/geode-core/src/main/java/com/gemstone/gemfire/cache/CacheFactory.java b/geode-core/src/main/java/com/gemstone/gemfire/cache/CacheFactory.java
old mode 100755
new mode 100644
index a5bcf59..991b27f
--- a/geode-core/src/main/java/com/gemstone/gemfire/cache/CacheFactory.java
+++ b/geode-core/src/main/java/com/gemstone/gemfire/cache/CacheFactory.java
@@ -19,6 +19,7 @@ package com.gemstone.gemfire.cache;
 
 import java.util.Properties;
 
+import com.gemstone.gemfire.distributed.ConfigurationProperties;
 import com.gemstone.gemfire.distributed.DistributedSystem;
 import com.gemstone.gemfire.distributed.internal.InternalDistributedSystem;
 import com.gemstone.gemfire.internal.GemFireVersion;
@@ -93,7 +94,8 @@ public class CacheFactory {
   }
   /**
    * Create a CacheFactory initialized with the given gemfire properties.
-   * For a list of valid gemfire properties see {@link DistributedSystem}.
+   * For a list of valid GemFire properties and their meanings
+   * see {@linkplain ConfigurationProperties}.
    * @param props the gemfire properties to initialize the factory with.
    * @since GemFire 6.5
    */
@@ -106,7 +108,8 @@ public class CacheFactory {
 
   /**
    * Sets a gemfire property that will be used when creating the Cache.
    * For a list of valid gemfire properties see {@link DistributedSystem}.
    * @param name the name of the gemfire property
    * @param value the value of the gemfire property
    * @return a reference to this CacheFactory object

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/e831aa06/geode-core/src/main/java/com/gemstone/gemfire/distributed/DistributedSystem.java
----------------------------------------------------------------------
@@ -106,7 +108,8 @@ public class CacheFactory {
   /**
    * Sets a gemfire property that will be used when creating the Cache.
-   * For a list of valid gemfire properties see {@link DistributedSystem}.
+   * For a list of valid GemFire properties and their meanings
+   * see {@link ConfigurationProperties}.
    * @param name the name of the gemfire property
    * @param value the value of the gemfire property